@@ -4,7 +4,7 @@
 #	Class 'ppm' representing fitted point process models.
 #
 #
-#	$Revision: 2.16 $	$Date: 2007/05/17 18:16:25 $
+#	$Revision: 2.17 $	$Date: 2007/10/23 09:14:19 $
 #
 #       An object of class 'ppm' contains the following:
 #
@@ -59,25 +59,34 @@ print.ppm <- function(x, ...) {
         if(multitype) {
             cat("Possible marks: \n")
             cat(paste(levels(mrk)))
+            cat("\n")
           }
 
         # ----- trend --------------------------
 
-        cat(paste("\n", s$trend$name, ":\n", sep=""))
+#       cat(paste("\n", s$trend$name, ":\n", sep=""))
 
 	if(!notrend) {
-		cat("Trend formula: ")
+		cat("\nTrend formula: ")
 		print(s$trend$formula)
         }
         
-        cat(paste("\n", s$trend$label, ":\n", sep=""))
+        cat(paste("\n", s$trend$label, ":", sep=""))
 
         tv <- s$trend$value
-        if(!is.list(tv))
-          print(tv)
-        else 
+        if(is.list(tv)) {
+          cat("\n")
           for(i in seq(tv))
             print(tv[[i]])
+        } else if(is.numeric(tv) && length(tv) == 1 && is.null(names(tv)))
+          # append to end of current line
+          cat("\t", paste(tv), "\n")
+        else {
+          cat("\n")
+          print(tv)
+        }
+
+        cat("\n")
         
         # ---- Interaction ----------------------------
 
